# Mathhole

[![codecov](https://codecov.io/gh/aaronclong/mathhole/branch/master/graph/badge.svg?token=JJMIWOX7IS)](https://codecov.io/gh/aaronclong/mathhole)

An extremely bad, unintelligent math library for a moron to learn.
Please don't use and if you do, it is at your own risk.